pub fn get_default_accelerators() -> Vec<Accelerator>Expand description
Returns every accelerator this build enables, in the order to try them.
pub fn get_default_accelerators() -> Vec<Accelerator>Returns every accelerator this build enables, in the order to try them.