pub fn install_compilation_cache_at(dir: &Path) -> Result<(), CacheError>Expand description
Points CubeCL’s compilation and autotune caches at dir, creating it
if it does not exist.
This is the entry point for a caller using this crate directly.